Changelog
---------

**Version 0.17.0**

- Update to latest `nv-sgl` with CoopVec support
- Native tensor implementation
- Linux crash fix

**Version 0.16.0**

- Native texture and structured buffer implementations
- Native function dispatches
- Lots of bug fixes

**Version 0.15.2**

- Correctly package slang files in wheel

**Version 0.15.0**

- Native buffer takes full reflection layout
- Add uniforms + cursor api to native buffer
- Update required version of `nv-sgl` to `0.9.0`

**Version 0.14.0**

- Update required version of `nv-sgl` to `0.8.0`
- Substantial native + python optimizations

**Version 0.13.0**

- Update required version of `nv-sgl` to `0.7.0`
- Native SlangPy backend re-enabled 
- Conversion of NDBuffer to native code 
- PyTorch integration refactor

**Version 0.12.0**

- Update required version of `nv-sgl` to `0.6.2`
- Re-enable broken Vulkan tests

**Version 0.11.0**

- Update required version of `nv-sgl` to `0.6.1`

**Version 0.10.0**

- Initial test release
